@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP;
 use vars '$VERSION';
-$VERSION = '0.5';
+$VERSION = '0.51';
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
 use XML::Compile::Util  qw/pack_type/;
@@ -290,14 +290,16 @@ sub _reader_encstyle_hook()
 {   my $self     = shift;
     my $envns    = $self->envelopeNS;
     my $style_r = $self->schemas->compile
-      ( READER => pack_type($envns, 'encodingStyle')
-      );
-    my $encstyle;
+      (READER => pack_type($envns, 'encodingStyle'));  # is attribute
+
+    my $encstyle;  # yes, closures!
 
     my $before = sub
-      { my $xml   = $_[0];
-        $encstyle = $style_r->(@_);
-        $xml->removeAttribute('encodingStyle');
+      { my ($xml, $path) = @_;
+        if(my $attr = $xml->getAttributeNode('encodingStyle'))
+        {   $encstyle = $style_r->($attr, $path);
+            $xml->removeAttribute('encodingStyle');
+        }
         $xml;
       };
 
