@@ -5,7 +5,7 @@
 
 package XML::Compile::Schema::XmlWriter;
 use vars '$VERSION';
-$VERSION = '0.5';
+$VERSION = '0.51';
 
 use strict;
 use warnings;
@@ -13,7 +13,7 @@ no warnings 'once';
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
 use List::Util    qw/first/;
-use XML::Compile::Util qw/unpack_type odd_elements/;
+use XML::Compile::Util qw/unpack_type odd_elements block_label/;
 
 
 # Each action implementation returns a code reference, which will be
@@ -57,7 +57,7 @@ sub tag_unqualified
     $name;
 }
 
-sub wrapper
+sub element_wrapper
 {   my ($path, $args, $processor) = @_;
     sub { my ($doc, $data) = @_;
           my $top = $processor->(@_);
@@ -65,6 +65,7 @@ sub wrapper
           $top;
         };
 }
+*attribute_wrapper = \&element_wrapper;
 
 sub wrapper_ns
 {   my ($path, $args, $processor, $index) = @_;
@@ -209,12 +210,13 @@ sub element_handler
 }
 
 sub block_handler
-{   my ($path, $args, $label, $min, $max, $process) = @_;
+{   my ($path, $args, $label, $min, $max, $process, $kind) = @_;
+    my $multi = block_label $kind, $label;
 
     if($min==0 && $max eq 'unbounded')
     {   return bless
         sub { my $doc    = shift;
-              my $values = delete shift->{$label};
+              my $values = delete shift->{$multi};
                 ref $values eq 'ARRAY' ? (map {$process->($doc, $_)} @$values)
               : defined $values        ? $process->($doc, $values)
               :                          ();
@@ -224,7 +226,7 @@ sub block_handler
     if($max eq 'unbounded')
     {   return bless
         sub { my $doc    = shift;
-              my $values = delete shift->{$label};
+              my $values = delete shift->{$multi};
               my @values = ref $values eq 'ARRAY' ? @$values
                          : defined $values ? $values : ();
 
@@ -268,7 +270,7 @@ sub block_handler
     my $opt = $max - $min;
     bless
     sub { my $doc    = shift;
-          my $values = delete shift->{$label};
+          my $values = delete shift->{$multi};
           my @values = ref $values eq 'ARRAY' ? @$values
                      : defined $values ? $values : ();
 
