@@ -7,14 +7,15 @@ use strict;
 
 package XML::Compile::Util;
 use vars '$VERSION';
-$VERSION = '0.5';
+$VERSION = '0.51';
 use base 'Exporter';
 
 our @EXPORT = qw/pack_type unpack_type pack_id unpack_id
-  odd_elements/;
+  odd_elements block_label/;
 
 use Log::Report 'xml-compile';
 
+
 sub pack_type($$) {
    defined $_[0] && defined $_[1]
        or report PANIC => "pack_type with undef `$_[0]' or `$_[1]'";
@@ -36,4 +37,14 @@ sub odd_elements(@)
     map {$i++ % 2 ? $_ : ()} @_;
 }
 
+
+my %block_abbrev = qw/sequence seq_  choice cho_  all all_  group gr_/;
+sub block_label($$)
+{   my ($kind, $label) = @_;
+    return $label if $kind eq 'element';
+
+    $label =~ s/^(?:seq|cho|all|gr)_//;
+    $block_abbrev{$kind} . $label;
+}
+
 1;
