@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::WSDL;
 use vars '$VERSION';
-$VERSION = '0.5';
+$VERSION = '0.51';
 use base 'XML::Compile';
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
@@ -94,7 +94,7 @@ sub addWSDL($)
 
     # WSDL 1.1 par 2.1.1 says: WSDL defs all in own name-space
     my $index = $self->{index};
-    my $toplevels = $spec->{import} || [];  # silly WSDL structure
+    my $toplevels = $spec->{gr_import} || [];  # silly WSDL structure
     foreach my $toplevel (@$toplevels)
     {   my $which = (keys %$toplevel)[0];   # only one
         next unless $which =~ m/^(?:service|message|binding|portType)$/;
